changeset 20510:b6ba69cec4b9

treewide: fstat64() -> fstat()
author Lauri Tirkkonen <lotheac@iki.fi>
date Tue, 16 Apr 2019 02:04:38 +0300
parents 508d717b544f
children bcfee9e02d54
files usr/src/cmd/backup/dump/dumpmain.c usr/src/cmd/backup/dump/dumptape.c usr/src/cmd/backup/restore/symtab.c usr/src/cmd/dumpadm/dconf.c usr/src/cmd/fm/fmd/common/fmd_ckpt.c usr/src/cmd/fm/fmd/common/fmd_log.c usr/src/cmd/fs.d/ufs/quotacheck/quotacheck.c usr/src/cmd/fs.d/ufs/repquota/repquota.c usr/src/cmd/fs.d/ufs/volcopy/volcopy.c usr/src/cmd/lofiadm/main.c usr/src/cmd/mdb/common/mdb/mdb_fdio.c usr/src/cmd/mkfile/mkfile.c usr/src/cmd/msgfmt/gnu_handle.c usr/src/cmd/msgfmt/msgfmt.c usr/src/cmd/ndmpd/tlm/tlm_backup_reader.c usr/src/cmd/ptools/pmap/pmap.c usr/src/cmd/ptools/preap/preap.c usr/src/cmd/ptools/ptree/ptree.c usr/src/cmd/savecore/savecore.c usr/src/cmd/ypcmd/makedbm.c usr/src/cmd/zdb/zdb.c usr/src/cmd/zlogin/zlogin.c usr/src/cmd/zonestat/zonestatd/zonestatd.c usr/src/cmd/zpool/zpool_vdev.c usr/src/lib/fm/libfmd_log/common/fmd_log.c usr/src/lib/fm/libfmd_log/common/fmd_log_impl.h usr/src/lib/libadm/common/putdev.c usr/src/lib/libadm/common/putdgrp.c usr/src/lib/libctf/common/ctf_lib.c usr/src/lib/libdtrace/common/dt_module.c usr/src/lib/libpam/pam_framework.c usr/src/lib/libsec/common/aclutils.c usr/src/lib/libsmbios/common/smbios_lib.c usr/src/lib/libvolmgt/common/volmgt_on_private.c usr/src/lib/libzfs/common/libzfs_import.c usr/src/lib/libzfs/common/libzfs_util.c usr/src/lib/libzpool/common/kernel.c usr/src/lib/scsi/plugins/smp/usmp/common/usmp.c
diffstat 38 files changed, 55 insertions(+), 55 deletions(-) [+]
line wrap: on
line diff
--- a/usr/src/cmd/backup/dump/dumpmain.c	Tue Apr 16 02:03:02 2019 +0300
+++ b/usr/src/cmd/backup/dump/dumpmain.c	Tue Apr 16 02:04:38 2019 +0300
@@ -1429,7 +1429,7 @@
 				return (-1);
 			}
 
-			if (fstat64(fd, &post_stat) < 0) {
+			if (fstat(fd, &post_stat) < 0) {
 				saverr = errno;
 				(void) close(fd);
 				errno = saverr;
--- a/usr/src/cmd/backup/dump/dumptape.c	Tue Apr 16 02:03:02 2019 +0300
+++ b/usr/src/cmd/backup/dump/dumptape.c	Tue Apr 16 02:04:38 2019 +0300
@@ -508,7 +508,7 @@
 					errmsg = strerror(errno);
 				}
 
-				if (fstat64(archivefd, &stats) < 0)
+				if (fstat(archivefd, &stats) < 0)
 				    stats.st_size = -1;
 
 				/* cast to keep lint&printf happy */
@@ -1070,7 +1070,7 @@
 	struct stat sbuf;
 	int	rewind;
 
-	if (fstat64(f, &sbuf) < 0) {
+	if (fstat(f, &sbuf) < 0) {
 		msg(gettext(
 		    "Cannot obtain status of output device `%s'\n"),
 		    tape);
--- a/usr/src/cmd/backup/restore/symtab.c	Tue Apr 16 02:03:02 2019 +0300
+++ b/usr/src/cmd/backup/restore/symtab.c	Tue Apr 16 02:04:38 2019 +0300
@@ -712,7 +712,7 @@
 		    gettext("cannot open symbol table file %s\n"), filename);
 		done(1);
 	}
-	if (fstat64(fd, &stbuf) < 0) {
+	if (fstat(fd, &stbuf) < 0) {
 		perror("stat");
 		(void) fprintf(stderr,
 		    gettext("cannot stat symbol table file %s\n"), filename);
--- a/usr/src/cmd/dumpadm/dconf.c	Tue Apr 16 02:03:02 2019 +0300
+++ b/usr/src/cmd/dumpadm/dconf.c	Tue Apr 16 02:04:38 2019 +0300
@@ -293,7 +293,7 @@
 	int fd = open64(path, O_RDONLY);
 
 	if (fd >= 0) {
-		int status = fstat64(fd, stp);
+		int status = fstat(fd, stp);
 		(void) close(fd);
 		return (status);
 	}
--- a/usr/src/cmd/fm/fmd/common/fmd_ckpt.c	Tue Apr 16 02:03:02 2019 +0300
+++ b/usr/src/cmd/fm/fmd/common/fmd_ckpt.c	Tue Apr 16 02:04:38 2019 +0300
@@ -151,7 +151,7 @@
 	if ((ckp->ckp_fd = open(ckp->ckp_src, O_RDONLY)) == -1)
 		return (-1); /* failed to open checkpoint file */
 
-	if (fstat64(ckp->ckp_fd, &st) == -1) {
+	if (fstat(ckp->ckp_fd, &st) == -1) {
 		err = errno;
 		(void) close(ckp->ckp_fd);
 		return (fmd_set_errno(err));
--- a/usr/src/cmd/fs.d/ufs/quotacheck/quotacheck.c	Tue Apr 16 02:03:02 2019 +0300
+++ b/usr/src/cmd/fs.d/ufs/quotacheck/quotacheck.c	Tue Apr 16 02:04:38 2019 +0300
@@ -453,7 +453,7 @@
 		close(fi);
 		return (1);
 	}
-	if (fstat64(fileno(qf), &statb) < 0) {
+	if (fstat(fileno(qf), &statb) < 0) {
 		perror(qffile);
 		fclose(qf);
 		close(fi);
--- a/usr/src/cmd/fs.d/ufs/repquota/repquota.c	Tue Apr 16 02:03:02 2019 +0300
+++ b/usr/src/cmd/fs.d/ufs/repquota/repquota.c	Tue Apr 16 02:04:38 2019 +0300
@@ -241,7 +241,7 @@
 		perror(qffile);
 		return (1);
 	}
-	if (fstat64(fileno(qf), &statb) < 0) {
+	if (fstat(fileno(qf), &statb) < 0) {
 		perror(qffile);
 		(void) fclose(qf);
 		return (1);
--- a/usr/src/cmd/fs.d/ufs/volcopy/volcopy.c	Tue Apr 16 02:03:02 2019 +0300
+++ b/usr/src/cmd/fs.d/ufs/volcopy/volcopy.c	Tue Apr 16 02:04:38 2019 +0300
@@ -199,7 +199,7 @@
 	struct statvfs64 stfs_buf;
 
 	*devtype = G_NO_DEV;
-	if (fstat64(*fdes, &st_buf) == -1)
+	if (fstat(*fdes, &st_buf) == -1)
 		return (-1);
 	if (!S_ISCHR(st_buf.st_mode) && !S_ISBLK(st_buf.st_mode)) {
 		if (S_ISFIFO(st_buf.st_mode))
--- a/usr/src/cmd/lofiadm/main.c	Tue Apr 16 02:03:02 2019 +0300
+++ b/usr/src/cmd/lofiadm/main.c	Tue Apr 16 02:04:38 2019 +0300
@@ -1552,7 +1552,7 @@
 	if (fcntl(uncompfd, F_SETLKW, &lock) == -1)
 		die(gettext("fcntl: %s"), filename);
 
-	if (fstat64(uncompfd, &statbuf) == -1) {
+	if (fstat(uncompfd, &statbuf) == -1) {
 		(void) close(uncompfd);
 		die(gettext("fstat: %s"), filename);
 	}
@@ -1743,7 +1743,7 @@
 			goto cleanup;
 	}
 
-	if (fstat64(compfd, &statbuf) == -1)
+	if (fstat(compfd, &statbuf) == -1)
 		goto cleanup;
 
 	/*
@@ -1818,7 +1818,7 @@
 	if (fd == -1) {
 		die(gettext("open: %s"), filename);
 	}
-	error = fstat64(fd, &buf);
+	error = fstat(fd, &buf);
 	if (error == -1) {
 		die(gettext("fstat: %s"), filename);
 	} else if (!S_ISLOFIABLE(buf.st_mode)) {
--- a/usr/src/cmd/mdb/common/mdb/mdb_fdio.c	Tue Apr 16 02:03:02 2019 +0300
+++ b/usr/src/cmd/mdb/common/mdb/mdb_fdio.c	Tue Apr 16 02:04:38 2019 +0300
@@ -299,7 +299,7 @@
 	 * If we are operating on a disk in raw mode, we must do our own
 	 * block-oriented i/o; otherwise we can just use read() and write().
 	 */
-	if (fstat64(fd, &st) == 0 && S_ISCHR(st.st_mode) &&
+	if (fstat(fd, &st) == 0 && S_ISCHR(st.st_mode) &&
 	    ioctl(fd, DKIOCINFO, &info) == 0)
 		io->io_ops = &fdio_bdev_ops;
 	else
--- a/usr/src/cmd/mkfile/mkfile.c	Tue Apr 16 02:03:02 2019 +0300
+++ b/usr/src/cmd/mkfile/mkfile.c	Tue Apr 16 02:04:38 2019 +0300
@@ -177,7 +177,7 @@
 				argc--;
 				continue;
 			}
-			if (fstat64(fd, &st) < 0) {
+			if (fstat(fd, &st) < 0) {
 				saverr = errno;
 				(void) fprintf(stderr, gettext(
 				    "Could not fstat64 %s: %s\n"),
--- a/usr/src/cmd/msgfmt/gnu_handle.c	Tue Apr 16 02:03:02 2019 +0300
+++ b/usr/src/cmd/msgfmt/gnu_handle.c	Tue Apr 16 02:04:38 2019 +0300
@@ -134,7 +134,7 @@
 		/* no alias file found */
 		return (0);
 	}
-	if (fstat64(fd, &statbuf) == -1) {
+	if (fstat(fd, &statbuf) == -1) {
 		(void) close(fd);
 		return (0);
 	}
--- a/usr/src/cmd/msgfmt/msgfmt.c	Tue Apr 16 02:03:02 2019 +0300
+++ b/usr/src/cmd/msgfmt/msgfmt.c	Tue Apr 16 02:04:38 2019 +0300
@@ -235,7 +235,7 @@
 		error(gettext(ERR_OPEN_FAILED), filename);
 		/* NOTREACHED */
 	}
-	if (fstat64(fd, &statbuf) == -1) {
+	if (fstat(fd, &statbuf) == -1) {
 		error(gettext(ERR_STAT_FAILED), filename);
 		/* NOTREACHED */
 	}
--- a/usr/src/cmd/ndmpd/tlm/tlm_backup_reader.c	Tue Apr 16 02:03:02 2019 +0300
+++ b/usr/src/cmd/ndmpd/tlm/tlm_backup_reader.c	Tue Apr 16 02:04:38 2019 +0300
@@ -256,7 +256,7 @@
 	if (section_name == NULL)
 		return (-TLM_NO_SCRATCH_SPACE);
 
-	if (fstat64(fd, attr) == -1) {
+	if (fstat(fd, attr) == -1) {
 		NDMP_LOG(LOG_DEBUG, "output_file_header stat failed.");
 		free(section_name);
 		return (-TLM_OPEN_ERR);
--- a/usr/src/cmd/ptools/pmap/pmap.c	Tue Apr 16 02:03:02 2019 +0300
+++ b/usr/src/cmd/ptools/pmap/pmap.c	Tue Apr 16 02:04:38 2019 +0300
@@ -412,7 +412,7 @@
 					continue;
 				}
 
-				if (fstat64(mapfd, &statbuf) != 0) {
+				if (fstat(mapfd, &statbuf) != 0) {
 					Prelease(Pr, prr_flags);
 					(void) close(mapfd);
 					(void) fprintf(stderr, "%s: cannot "
@@ -469,7 +469,7 @@
 			if (Pstate(Pr) != PS_DEAD) {
 				struct stat newbuf;
 
-				if (fstat64(mapfd, &newbuf) != 0 ||
+				if (fstat(mapfd, &newbuf) != 0 ||
 				    memcmp(&newbuf.st_mtim, &statbuf.st_mtim,
 				    sizeof (newbuf.st_mtim)) != 0) {
 					if (stacks != NULL) {
--- a/usr/src/cmd/ptools/preap/preap.c	Tue Apr 16 02:03:02 2019 +0300
+++ b/usr/src/cmd/ptools/preap/preap.c	Tue Apr 16 02:04:38 2019 +0300
@@ -64,7 +64,7 @@
 	 * confirm this is a regular file provided by /proc.
 	 */
 	if ((fd = open64(path, O_RDONLY)) >= 0) {
-		if (fstat64(fd, &st) != 0 || !S_ISREG(st.st_mode) ||
+		if (fstat(fd, &st) != 0 || !S_ISREG(st.st_mode) ||
 		    strcmp(st.st_fstype, "proc") != 0) {
 			(void) close(fd);
 			fd = -1;
--- a/usr/src/cmd/ptools/ptree/ptree.c	Tue Apr 16 02:03:02 2019 +0300
+++ b/usr/src/cmd/ptools/ptree/ptree.c	Tue Apr 16 02:04:38 2019 +0300
@@ -414,7 +414,7 @@
 
 	if ((fd = contract_open(ctid, "process", "status", O_RDONLY)) == -1)
 		return;
-	if (fstat64(fd, &st) == -1 || ct_status_read(fd, CTD_COMMON, &hdl)) {
+	if (fstat(fd, &st) == -1 || ct_status_read(fd, CTD_COMMON, &hdl)) {
 		(void) close(fd);
 		return;
 	}
--- a/usr/src/cmd/savecore/savecore.c	Tue Apr 16 02:03:02 2019 +0300
+++ b/usr/src/cmd/savecore/savecore.c	Tue Apr 16 02:04:38 2019 +0300
@@ -292,7 +292,7 @@
 static void
 Fstat(int fd, Stat_t *sb, const char *fname)
 {
-	if (fstat64(fd, sb) != 0)
+	if (fstat(fd, sb) != 0)
 		logprint(SC_SL_ERR | SC_EXIT_ERR, "fstat(\"%s\"): %s", fname,
 		    strerror(errno));
 }
--- a/usr/src/cmd/ypcmd/makedbm.c	Tue Apr 16 02:03:02 2019 +0300
+++ b/usr/src/cmd/ypcmd/makedbm.c	Tue Apr 16 02:04:38 2019 +0300
@@ -96,7 +96,7 @@
 		}
 	}
 
-	if (inode_dev_valid != 0 && fstat64(filedes, &sb) == 0) {
+	if (inode_dev_valid != 0 && fstat(filedes, &sb) == 0) {
 		if (sb.st_ino == inode && sb.st_dev == dev) {
 			/* Keep open; pretend successful */
 			return (0);
@@ -311,7 +311,7 @@
 
 		if (strcmp(infile, "-") != 0)
 			infp = fopen(infile, "r");
-		else if (fstat64(fileno(stdin), &statbuf) == -1) {
+		else if (fstat(fileno(stdin), &statbuf) == -1) {
 			fprintf(stderr, "makedbm: can't open stdin\n");
 			exit(1);
 		} else
@@ -330,7 +330,7 @@
 
 		if (lockf(fileno(outfp), F_TLOCK, 0) == 0) {
 			/* Got exclusive access; save inode and dev */
-			if (fstat64(fileno(outfp), &statbuf) != 0) {
+			if (fstat(fileno(outfp), &statbuf) != 0) {
 				fprintf(stderr, "makedbm: can't fstat ");
 				perror(tmpdirbuf);
 				exit(1);
--- a/usr/src/cmd/zdb/zdb.c	Tue Apr 16 02:03:02 2019 +0300
+++ b/usr/src/cmd/zdb/zdb.c	Tue Apr 16 02:04:38 2019 +0300
@@ -2428,7 +2428,7 @@
 		exit(1);
 	}
 
-	if (fstat64(fd, &statbuf) != 0) {
+	if (fstat(fd, &statbuf) != 0) {
 		(void) printf("failed to stat '%s': %s\n", cachefile,
 		    strerror(errno));
 		exit(1);
@@ -2622,7 +2622,7 @@
 		exit(1);
 	}
 
-	if (fstat64(fd, &statbuf) != 0) {
+	if (fstat(fd, &statbuf) != 0) {
 		(void) fprintf(stderr, "failed to stat '%s': %s\n", path,
 		    strerror(errno));
 		(void) close(fd);
--- a/usr/src/cmd/zlogin/zlogin.c	Tue Apr 16 02:03:02 2019 +0300
+++ b/usr/src/cmd/zlogin/zlogin.c	Tue Apr 16 02:04:38 2019 +0300
@@ -716,7 +716,7 @@
 	char ibuf[ZLOGIN_RDBUFSIZ];
 
 	/* Check how much data is already in the pipe */
-	if (fstat64(appin_fd, &sb) == -1) {
+	if (fstat(appin_fd, &sb) == -1) {
 		perror("stat failed");
 		return (-1);
 	}
--- a/usr/src/cmd/zonestat/zonestatd/zonestatd.c	Tue Apr 16 02:03:02 2019 +0300
+++ b/usr/src/cmd/zonestat/zonestatd/zonestatd.c	Tue Apr 16 02:04:38 2019 +0300
@@ -2569,7 +2569,7 @@
 
 	if ((*fd = open64(path, O_RDONLY, 0)) >= 0 &&
 	    (oret = ea_fdopen(eaf, *fd, NULL, flags, O_RDONLY)) == 0)
-		ret = fstat64(*fd, stat);
+		ret = fstat(*fd, stat);
 
 	if (*fd < 0 || oret < 0 || ret < 0) {
 		struct timespec ts;
--- a/usr/src/cmd/zpool/zpool_vdev.c	Tue Apr 16 02:03:02 2019 +0300
+++ b/usr/src/cmd/zpool/zpool_vdev.c	Tue Apr 16 02:04:38 2019 +0300
@@ -688,7 +688,7 @@
 				 * this device altogether.
 				 */
 				if ((fd = open(path, O_RDONLY)) >= 0) {
-					err = fstat64(fd, &statbuf);
+					err = fstat(fd, &statbuf);
 					(void) close(fd);
 				} else {
 					err = stat64(path, &statbuf);
--- a/usr/src/lib/fm/libfmd_log/common/fmd_log.c	Tue Apr 16 02:03:02 2019 +0300
+++ b/usr/src/lib/fm/libfmd_log/common/fmd_log.c	Tue Apr 16 02:04:38 2019 +0300
@@ -393,7 +393,7 @@
 		return (fmd_log_open_err(lp, errp, EFDL_NOMEM));
 
 	if ((lp->log_fd = open64(name, O_RDONLY)) == -1 ||
-	    fstat64(lp->log_fd, &lp->log_stat) == -1 ||
+	    fstat(lp->log_fd, &lp->log_stat) == -1 ||
 	    (fd = dup(lp->log_fd)) == -1)
 		return (fmd_log_open_err(lp, errp, errno));
 
--- a/usr/src/lib/fm/libfmd_log/common/fmd_log_impl.h	Tue Apr 16 02:03:02 2019 +0300
+++ b/usr/src/lib/fm/libfmd_log/common/fmd_log_impl.h	Tue Apr 16 02:04:38 2019 +0300
@@ -39,7 +39,7 @@
 #endif
 
 struct fmd_log {
-	struct stat log_stat;		/* fstat64() information for log file */
+	struct stat log_stat;		/* fstat() information for log file */
 	ea_file_t log_ea;		/* libexacct handle for log file */
 	char *log_path;			/* log file pathname used for open */
 	char *log_version;		/* creator version string */
--- a/usr/src/lib/libadm/common/putdev.c	Tue Apr 16 02:03:02 2019 +0300
+++ b/usr/src/lib/libadm/common/putdev.c	Tue Apr 16 02:04:38 2019 +0300
@@ -179,7 +179,7 @@
 	    if ((fd = open(oldname, O_WRONLY)) == -1)
 		return (NULL);
 
-	    if (fstat64(fd, &sbuf) == -1) {
+	    if (fstat(fd, &sbuf) == -1) {
 		(void) close(fd);
 		return (NULL);
 	    }
--- a/usr/src/lib/libadm/common/putdgrp.c	Tue Apr 16 02:03:02 2019 +0300
+++ b/usr/src/lib/libadm/common/putdgrp.c	Tue Apr 16 02:04:38 2019 +0300
@@ -148,7 +148,7 @@
 		if ((fd = open(oldname, O_WRONLY)) == -1)
 			return (NULL);
 
-		if (fstat64(fd, &sbuf) == -1) {
+		if (fstat(fd, &sbuf) == -1) {
 			(void) close(fd);
 			return (NULL);
 		}
--- a/usr/src/lib/libctf/common/ctf_lib.c	Tue Apr 16 02:03:02 2019 +0300
+++ b/usr/src/lib/libctf/common/ctf_lib.c	Tue Apr 16 02:04:38 2019 +0300
@@ -437,7 +437,7 @@
 	bzero(&strsect, sizeof (ctf_sect_t));
 	bzero(&hdr.ctf, sizeof (hdr));
 
-	if (fstat64(fd, &st) == -1)
+	if (fstat(fd, &st) == -1)
 		return (ctf_set_open_errno(errp, errno));
 
 	if ((nbytes = pread64(fd, &hdr.ctf, sizeof (hdr), 0)) <= 0)
--- a/usr/src/lib/libdtrace/common/dt_module.c	Tue Apr 16 02:03:02 2019 +0300
+++ b/usr/src/lib/libdtrace/common/dt_module.c	Tue Apr 16 02:04:38 2019 +0300
@@ -1073,7 +1073,7 @@
 	(void) snprintf(fname, sizeof (fname),
 	    "%s/%s/object", OBJFS_ROOT, name);
 
-	if ((fd = open(fname, O_RDONLY)) == -1 || fstat64(fd, &st) == -1 ||
+	if ((fd = open(fname, O_RDONLY)) == -1 || fstat(fd, &st) == -1 ||
 	    (dmp = dt_module_create(dtp, name)) == NULL) {
 		dt_dprintf("failed to open %s: %s\n", fname, strerror(errno));
 		(void) close(fd);
--- a/usr/src/lib/libpam/pam_framework.c	Tue Apr 16 02:03:02 2019 +0300
+++ b/usr/src/lib/libpam/pam_framework.c	Tue Apr 16 02:04:38 2019 +0300
@@ -1936,7 +1936,7 @@
 		return (0);
 	}
 	/* Check the ownership and file modes */
-	if (fstat64(fd, &stb) < 0) {
+	if (fstat(fd, &stb) < 0) {
 		__pam_log(LOG_AUTH | LOG_ALERT,
 		    "open_pam_conf[%d:%s]: stat(%s) failed: %s",
 		    pamh->include_depth, pam_trace_cname(pamh), config,
--- a/usr/src/lib/libsec/common/aclutils.c	Tue Apr 16 02:03:02 2019 +0300
+++ b/usr/src/lib/libsec/common/aclutils.c	Tue Apr 16 02:04:38 2019 +0300
@@ -172,7 +172,7 @@
 		error = acl(fname, getcmd, acl_info->acl_cnt,
 		    acl_info->acl_aclp);
 	} else {
-		stat_error = fstat64(fd, &statbuf);
+		stat_error = fstat(fd, &statbuf);
 		error = facl(fd, getcmd, acl_info->acl_cnt,
 		    acl_info->acl_aclp);
 	}
@@ -259,7 +259,7 @@
 			return (-1);
 		acl_flavor_target = pathconf(acl_inp->file, _PC_ACL_ENABLED);
 	} else {
-		stat_error = fstat64(acl_inp->fd, &statbuf);
+		stat_error = fstat(acl_inp->fd, &statbuf);
 		if (stat_error)
 			return (-1);
 		acl_flavor_target = fpathconf(acl_inp->fd, _PC_ACL_ENABLED);
--- a/usr/src/lib/libsmbios/common/smbios_lib.c	Tue Apr 16 02:03:02 2019 +0300
+++ b/usr/src/lib/libsmbios/common/smbios_lib.c	Tue Apr 16 02:04:38 2019 +0300
@@ -203,7 +203,7 @@
 {
 	struct stat st1, st2;
 
-	if (stat64(SMB_BIOS_DEVICE, &st1) == 0 && fstat64(fd, &st2) == 0 &&
+	if (stat64(SMB_BIOS_DEVICE, &st1) == 0 && fstat(fd, &st2) == 0 &&
 	    S_ISCHR(st2.st_mode) && st1.st_rdev == st2.st_rdev)
 		return (smb_biosopen(fd, version, flags, errp));
 	else
--- a/usr/src/lib/libvolmgt/common/volmgt_on_private.c	Tue Apr 16 02:03:02 2019 +0300
+++ b/usr/src/lib/libvolmgt/common/volmgt_on_private.c	Tue Apr 16 02:04:38 2019 +0300
@@ -96,7 +96,7 @@
 		goto dun;
 	}
 
-	if (fstat64(fd, &sb) < 0) {
+	if (fstat(fd, &sb) < 0) {
 		goto dun;
 	}
 
@@ -308,7 +308,7 @@
 		}
 
 		/* stat the device */
-		if (fstat64(fd, &sb) < 0) {
+		if (fstat(fd, &sb) < 0) {
 			free(cn);
 			(void) close(fd);
 			continue;	/* ain't there: can't be a match */
@@ -435,7 +435,7 @@
 		goto dun;
 	}
 
-	if (fstat64(fd, &sb) < 0) {
+	if (fstat(fd, &sb) < 0) {
 		goto dun;
 	}
 
--- a/usr/src/lib/libzfs/common/libzfs_import.c	Tue Apr 16 02:03:02 2019 +0300
+++ b/usr/src/lib/libzfs/common/libzfs_import.c	Tue Apr 16 02:04:38 2019 +0300
@@ -853,7 +853,7 @@
 
 	*config = NULL;
 
-	if (fstat64(fd, &statbuf) == -1)
+	if (fstat(fd, &statbuf) == -1)
 		return (-1);
 	size = P2ALIGN_TYPED(statbuf.st_size, sizeof (vdev_label_t), uint64_t);
 
@@ -1034,7 +1034,7 @@
 	 * Ignore failed stats.  We only want regular
 	 * files, character devs and block devs.
 	 */
-	if (fstat64(fd, &statbuf) != 0 ||
+	if (fstat(fd, &statbuf) != 0 ||
 	    (!S_ISREG(statbuf.st_mode) &&
 	    !S_ISCHR(statbuf.st_mode) &&
 	    !S_ISBLK(statbuf.st_mode))) {
@@ -1075,7 +1075,7 @@
 	vdev_label_t *label;
 	uint64_t size;
 
-	if (fstat64(fd, &statbuf) == -1)
+	if (fstat(fd, &statbuf) == -1)
 		return (0);
 	size = P2ALIGN_TYPED(statbuf.st_size, sizeof (vdev_label_t), uint64_t);
 
@@ -1316,7 +1316,7 @@
 		return (NULL);
 	}
 
-	if (fstat64(fd, &statbuf) != 0) {
+	if (fstat(fd, &statbuf) != 0) {
 		zfs_error_aux(hdl, "%s", strerror(errno));
 		(void) close(fd);
 		(void) zfs_error(hdl, EZFS_BADCACHE,
--- a/usr/src/lib/libzfs/common/libzfs_util.c	Tue Apr 16 02:03:02 2019 +0300
+++ b/usr/src/lib/libzfs/common/libzfs_util.c	Tue Apr 16 02:04:38 2019 +0300
@@ -1579,7 +1579,7 @@
 		return (err);
 	}
 
-	if (fstat64(fd, &ss) == -1) {
+	if (fstat(fd, &ss) == -1) {
 		err = errno;
 		(void) close(fd);
 		return (err);
--- a/usr/src/lib/libzpool/common/kernel.c	Tue Apr 16 02:03:02 2019 +0300
+++ b/usr/src/lib/libzpool/common/kernel.c	Tue Apr 16 02:04:38 2019 +0300
@@ -428,7 +428,7 @@
 		fd = open64(path, O_RDONLY);
 		if (fd == -1)
 			return (errno);
-		if (fstat64(fd, &st) == -1) {
+		if (fstat(fd, &st) == -1) {
 			close(fd);
 			return (errno);
 		}
@@ -470,7 +470,7 @@
 	if (fd == -1)
 		return (errno);
 
-	if (fstat64(fd, &st) == -1) {
+	if (fstat(fd, &st) == -1) {
 		close(fd);
 		return (errno);
 	}
@@ -561,7 +561,7 @@
 {
 	struct stat st;
 
-	if (fstat64(vp->v_fd, &st) == -1) {
+	if (fstat(vp->v_fd, &st) == -1) {
 		close(vp->v_fd);
 		return (errno);
 	}
@@ -784,7 +784,7 @@
 	struct stat st;
 	vnode_t *vp = (vnode_t *)file->_fd;
 
-	if (fstat64(vp->v_fd, &st) == -1) {
+	if (fstat(vp->v_fd, &st) == -1) {
 		vn_close(vp);
 		return (errno);
 	}
--- a/usr/src/lib/scsi/plugins/smp/usmp/common/usmp.c	Tue Apr 16 02:03:02 2019 +0300
+++ b/usr/src/lib/scsi/plugins/smp/usmp/common/usmp.c	Tue Apr 16 02:04:38 2019 +0300
@@ -105,7 +105,7 @@
 		return (NULL);
 	}
 
-	if (fstat64(dp->ud_fd, &st) != 0) {
+	if (fstat(dp->ud_fd, &st) != 0) {
 		(void) smp_error(ESMP_BADTARGET,
 		    "failed to stat %s: %s", target_name, strerror(errno));
 		(void) close(dp->ud_fd);
--- a/usr/src/cmd/fm/fmd/common/fmd_log.c	Tue Apr 16 02:03:02 2019 +0300
+++ b/usr/src/cmd/fm/fmd/common/fmd_log.c	Tue Apr 16 02:04:38 2019 +0300
@@ -56,7 +56,7 @@
  * formats we still support encoding the reference as (major, minor, inode).
  * Note that we break out of the file's dev_t into its two 32-bit components to
  * permit development of either 32-bit or 64-bit log readers and writers; the
  * LFS APIs do not yet export a 64-bit dev_t to fstat64(), so there is no way
  * for a 32-bit application to retrieve and store a 64-bit dev_t.
  *
  * In order to replay events in the event of an fmd crash, events are initially
@@ -378,7 +378,7 @@
 
 top:
 	if ((lp->log_fd = open64(lp->log_name, oflags, 0644)) == -1 ||
-	    fstat64(lp->log_fd, &lp->log_stat) == -1) {
+	    fstat(lp->log_fd, &lp->log_stat) == -1) {
 		fmd_error(EFMD_LOG_OPEN, "failed to open log %s", lp->log_name);
 		fmd_log_close(lp);
 		return (NULL);
@@ -56,7 +56,7 @@
  * Note that we break out of the file's dev_t into its two 32-bit components to
  * permit development of either 32-bit or 64-bit log readers and writers; the
- * LFS APIs do not yet export a 64-bit dev_t to fstat64(), so there is no way
+ * LFS APIs do not yet export a 64-bit dev_t to fstat(), so there is no way
  * for a 32-bit application to retrieve and store a 64-bit dev_t.
  *